@@ -54,18 +54,18 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_ec2
-import aws_cdk.aws_iam
-import aws_cdk.aws_kms
-import aws_cdk.aws_rds
-import aws_cdk.aws_secretsmanager
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_rds as _aws_cdk_aws_rds_ceddda9d
+import aws_cdk.aws_secretsmanager as _aws_cdk_aws_secretsmanager_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.aws_rds.IServerlessCluster)
+@jsii.implements(_aws_cdk_aws_rds_ceddda9d.IServerlessCluster)
 class ServerlessClusterFromSnapshot(
-    aws_cdk.Resource,
+    _aws_cdk_ceddda9d.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-serverless-cluster-from-snapshot.ServerlessClusterFromSnapshot",
 ):
@@ -77,25 +77,25 @@ class ServerlessClusterFromSnapshot(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        engine: aws_cdk.aws_rds.IClusterEngine,
+        engine: _aws_cdk_aws_rds_ceddda9d.IClusterEngine,
         snapshot_identifier: builtins.str,
-        vpc: aws_cdk.aws_ec2.IVpc,
-        backup_retention: typing.Optional[aws_cdk.Duration] = None,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+        backup_retention: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
         cluster_identifier: typing.Optional[builtins.str] = None,
-        credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
+        credentials: typing.Optional[_aws_cdk_aws_rds_ceddda9d.Credentials] = None,
         default_database_name: typing.Optional[builtins.str] = None,
         deletion_protection: typing.Optional[builtins.bool] = None,
         enable_data_api: typing.Optional[builtins.bool] = None,
-        parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
-        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-        storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-        subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
-        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        parameter_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.IParameterGroup] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        scaling: typing.Optional[typing.Union[_aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+        storage_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
+        subnet_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.ISubnetGroup] = None,
+        vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -120,29 +120,7 @@ class ServerlessClusterFromSnapshot(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                engine: aws_cdk.aws_rds.IClusterEngine,
-                snapshot_identifier: builtins.str,
-                vpc: aws_cdk.aws_ec2.IVpc,
-                backup_retention: typing.Optional[aws_cdk.Duration] = None,
-                cluster_identifier: typing.Optional[builtins.str] = None,
-                credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
-                default_database_name: typing.Optional[builtins.str] = None,
-                deletion_protection: typing.Optional[builtins.bool] = None,
-                enable_data_api: typing.Optional[builtins.bool] = None,
-                parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
-                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-                storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-                subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
-                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__02b4e7be41e42a4d0aba31d2cde08b3d9da054f652ab229cf3fcdf2fba029256)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ServerlessClusterFromSnapshotProps(
@@ -171,12 +149,12 @@ class ServerlessClusterFromSnapshot(
         self,
         id: builtins.str,
         *,
-        secret: aws_cdk.aws_secretsmanager.ISecret,
-        automatically_after: typing.Optional[aws_cdk.Duration] = None,
-        endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
+        secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+        automatically_after: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+        endpoint: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IInterfaceVpcEndpoint] = None,
         exclude_characters: typing.Optional[builtins.str] = None,
-        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-    ) -> aws_cdk.aws_secretsmanager.SecretRotation:
+        vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+    ) -> _aws_cdk_aws_secretsmanager_ceddda9d.SecretRotation:
         '''(deprecated) Adds the multi user rotation to this cluster.
 
         :param id: -
@@ -189,19 +167,9 @@ class ServerlessClusterFromSnapshot(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                *,
-                secret: aws_cdk.aws_secretsmanager.ISecret,
-                automatically_after: typing.Optional[aws_cdk.Duration] = None,
-                endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
-                exclude_characters: typing.Optional[builtins.str] = None,
-                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6fcef260575cff50f6020a8b1026eca3010c75a62054850c10123d8a2a5fcf86)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        options = aws_cdk.aws_rds.RotationMultiUserOptions(
+        options = _aws_cdk_aws_rds_ceddda9d.RotationMultiUserOptions(
             secret=secret,
             automatically_after=automatically_after,
             endpoint=endpoint,
@@ -209,17 +177,17 @@ class ServerlessClusterFromSnapshot(
             vpc_subnets=vpc_subnets,
         )
 
-        return typing.cast(aws_cdk.aws_secretsmanager.SecretRotation, jsii.invoke(self, "addRotationMultiUser", [id, options]))
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.SecretRotation, jsii.invoke(self, "addRotationMultiUser", [id, options]))
 
     @jsii.member(jsii_name="addRotationSingleUser")
     def add_rotation_single_user(
         self,
         *,
-        automatically_after: typing.Optional[aws_cdk.Duration] = None,
-        endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
+        automatically_after: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+        endpoint: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IInterfaceVpcEndpoint] = None,
         exclude_characters: typing.Optional[builtins.str] = None,
-        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-    ) -> aws_cdk.aws_secretsmanager.SecretRotation:
+        vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+    ) -> _aws_cdk_aws_secretsmanager_ceddda9d.SecretRotation:
         '''(deprecated) Adds the single user rotation of the master password to this cluster.
 
         :param automatically_after: Specifies the number of days after the previous rotation before Secrets Manager triggers the next automatic rotation. Default: - 30 days
@@ -229,30 +197,30 @@ class ServerlessClusterFromSnapshot(
 
         :stability: deprecated
         '''
-        options = aws_cdk.aws_rds.RotationSingleUserOptions(
+        options = _aws_cdk_aws_rds_ceddda9d.RotationSingleUserOptions(
             automatically_after=automatically_after,
             endpoint=endpoint,
             exclude_characters=exclude_characters,
             vpc_subnets=vpc_subnets,
         )
 
-        return typing.cast(aws_cdk.aws_secretsmanager.SecretRotation, jsii.invoke(self, "addRotationSingleUser", [options]))
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.SecretRotation, jsii.invoke(self, "addRotationSingleUser", [options]))
 
     @jsii.member(jsii_name="asSecretAttachmentTarget")
     def as_secret_attachment_target(
         self,
-    ) -> aws_cdk.aws_secretsmanager.SecretAttachmentTargetProps:
+    ) -> _aws_cdk_aws_secretsmanager_ceddda9d.SecretAttachmentTargetProps:
         '''(deprecated) Renders the secret attachment target specifications.
 
         :stability: deprecated
         '''
-        return typing.cast(aws_cdk.aws_secretsmanager.SecretAttachmentTargetProps, jsii.invoke(self, "asSecretAttachmentTarget", []))
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.SecretAttachmentTargetProps, jsii.invoke(self, "asSecretAttachmentTarget", []))
 
     @jsii.member(jsii_name="grantDataApiAccess")
     def grant_data_api_access(
         self,
-        grantee: aws_cdk.aws_iam.IGrantable,
-    ) -> aws_cdk.aws_iam.Grant:
+        grantee: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+    ) -> _aws_cdk_aws_iam_ceddda9d.Grant:
         '''(deprecated) Grant the given identity to access to the Data API, including read access to the secret attached to the cluster if present.
 
         :param grantee: The principal to grant access to.
@@ -260,11 +228,9 @@ class ServerlessClusterFromSnapshot(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e7470b0229ed4dc476cf44a05c9cace0d0dd92a87419e9ff947e198099945223)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantDataApiAccess", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Grant, jsii.invoke(self, "grantDataApiAccess", [grantee]))
 
     @builtins.property
     @jsii.member(jsii_name="clusterArn")
@@ -277,12 +243,12 @@ class ServerlessClusterFromSnapshot(
 
     @builtins.property
     @jsii.member(jsii_name="clusterEndpoint")
-    def cluster_endpoint(self) -> aws_cdk.aws_rds.Endpoint:
+    def cluster_endpoint(self) -> _aws_cdk_aws_rds_ceddda9d.Endpoint:
         '''(deprecated) The endpoint to use for read/write operations.
 
         :stability: deprecated
         '''
-        return typing.cast(aws_cdk.aws_rds.Endpoint, jsii.get(self, "clusterEndpoint"))
+        return typing.cast(_aws_cdk_aws_rds_ceddda9d.Endpoint, jsii.get(self, "clusterEndpoint"))
 
     @builtins.property
     @jsii.member(jsii_name="clusterIdentifier")
@@ -295,30 +261,30 @@ class ServerlessClusterFromSnapshot(
 
     @builtins.property
     @jsii.member(jsii_name="clusterReadEndpoint")
-    def cluster_read_endpoint(self) -> aws_cdk.aws_rds.Endpoint:
+    def cluster_read_endpoint(self) -> _aws_cdk_aws_rds_ceddda9d.Endpoint:
         '''(deprecated) The endpoint to use for read/write operations.
 
         :stability: deprecated
         '''
-        return typing.cast(aws_cdk.aws_rds.Endpoint, jsii.get(self, "clusterReadEndpoint"))
+        return typing.cast(_aws_cdk_aws_rds_ceddda9d.Endpoint, jsii.get(self, "clusterReadEndpoint"))
 
     @builtins.property
     @jsii.member(jsii_name="connections")
-    def connections(self) -> aws_cdk.aws_ec2.Connections:
+    def connections(self) -> _aws_cdk_aws_ec2_ceddda9d.Connections:
         '''(deprecated) Access to the network connections.
 
         :stability: deprecated
         '''
-        return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.Connections, jsii.get(self, "connections"))
 
     @builtins.property
     @jsii.member(jsii_name="secret")
-    def secret(self) -> typing.Optional[aws_cdk.aws_secretsmanager.ISecret]:
+    def secret(self) -> typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.ISecret]:
         '''(deprecated) The secret attached to this cluster.
 
         :stability: deprecated
         '''
-        return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.ISecret], jsii.get(self, "secret"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.ISecret], jsii.get(self, "secret"))
 
     @builtins.property
     @jsii.member(jsii_name="enableDataApi")
@@ -331,9 +297,7 @@ class ServerlessClusterFromSnapshot(
     @_enable_data_api.setter
     def _enable_data_api(self, value: typing.Optional[builtins.bool]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.bool]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__55266b5c88e611e9ec1495d5d65d3a04e84a3c99a81ba74c3dc8a361e1d012f0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableDataApi", value)
 
@@ -364,22 +328,22 @@ class ServerlessClusterFromSnapshotProps:
     def __init__(
         self,
         *,
-        engine: aws_cdk.aws_rds.IClusterEngine,
+        engine: _aws_cdk_aws_rds_ceddda9d.IClusterEngine,
         snapshot_identifier: builtins.str,
-        vpc: aws_cdk.aws_ec2.IVpc,
-        backup_retention: typing.Optional[aws_cdk.Duration] = None,
+        vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+        backup_retention: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
         cluster_identifier: typing.Optional[builtins.str] = None,
-        credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
+        credentials: typing.Optional[_aws_cdk_aws_rds_ceddda9d.Credentials] = None,
         default_database_name: typing.Optional[builtins.str] = None,
         deletion_protection: typing.Optional[builtins.bool] = None,
         enable_data_api: typing.Optional[builtins.bool] = None,
-        parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
-        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-        storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-        subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
-        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        parameter_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.IParameterGroup] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        scaling: typing.Optional[typing.Union[_aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+        storage_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
+        subnet_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.ISubnetGroup] = None,
+        vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(deprecated) Properties to configure an Aurora Serverless Cluster.
 
@@ -403,31 +367,11 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         if isinstance(scaling, dict):
-            scaling = aws_cdk.aws_rds.ServerlessScalingOptions(**scaling)
+            scaling = _aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions(**scaling)
         if isinstance(vpc_subnets, dict):
-            vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+            vpc_subnets = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**vpc_subnets)
         if __debug__:
-            def stub(
-                *,
-                engine: aws_cdk.aws_rds.IClusterEngine,
-                snapshot_identifier: builtins.str,
-                vpc: aws_cdk.aws_ec2.IVpc,
-                backup_retention: typing.Optional[aws_cdk.Duration] = None,
-                cluster_identifier: typing.Optional[builtins.str] = None,
-                credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
-                default_database_name: typing.Optional[builtins.str] = None,
-                deletion_protection: typing.Optional[builtins.bool] = None,
-                enable_data_api: typing.Optional[builtins.bool] = None,
-                parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
-                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-                storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-                subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
-                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__19f89db333d90ee77c4f24c45d7dd089f98417f7ff36c23d822417ea3efe321c)
             check_type(argname="argument engine", value=engine, expected_type=type_hints["engine"])
             check_type(argname="argument snapshot_identifier", value=snapshot_identifier, expected_type=type_hints["snapshot_identifier"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
@@ -444,7 +388,7 @@ class ServerlessClusterFromSnapshotProps:
             check_type(argname="argument storage_encryption_key", value=storage_encryption_key, expected_type=type_hints["storage_encryption_key"])
             check_type(argname="argument subnet_group", value=subnet_group, expected_type=type_hints["subnet_group"])
             check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "engine": engine,
             "snapshot_identifier": snapshot_identifier,
             "vpc": vpc,
@@ -477,14 +421,14 @@ class ServerlessClusterFromSnapshotProps:
             self._values["vpc_subnets"] = vpc_subnets
 
     @builtins.property
-    def engine(self) -> aws_cdk.aws_rds.IClusterEngine:
+    def engine(self) -> _aws_cdk_aws_rds_ceddda9d.IClusterEngine:
         '''(deprecated) What kind of database to start.
 
         :stability: deprecated
         '''
         result = self._values.get("engine")
         assert result is not None, "Required property 'engine' is missing"
-        return typing.cast(aws_cdk.aws_rds.IClusterEngine, result)
+        return typing.cast(_aws_cdk_aws_rds_ceddda9d.IClusterEngine, result)
 
     @builtins.property
     def snapshot_identifier(self) -> builtins.str:
@@ -501,17 +445,17 @@ class ServerlessClusterFromSnapshotProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
         '''(deprecated) The VPC that this Aurora Serverless cluster has been created in.
 
         :stability: deprecated
         '''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.IVpc, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, result)
 
     @builtins.property
-    def backup_retention(self) -> typing.Optional[aws_cdk.Duration]:
+    def backup_retention(self) -> typing.Optional[_aws_cdk_ceddda9d.Duration]:
         '''(deprecated) The number of days during which automatic DB snapshots are retained.
 
         Automatic backup retention cannot be disabled on serverless clusters.
@@ -522,7 +466,7 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("backup_retention")
-        return typing.cast(typing.Optional[aws_cdk.Duration], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.Duration], result)
 
     @builtins.property
     def cluster_identifier(self) -> typing.Optional[builtins.str]:
@@ -536,7 +480,7 @@ class ServerlessClusterFromSnapshotProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def credentials(self) -> typing.Optional[aws_cdk.aws_rds.Credentials]:
+    def credentials(self) -> typing.Optional[_aws_cdk_aws_rds_ceddda9d.Credentials]:
         '''(deprecated) Credentials for the administrative user.
 
         :default: - A username of 'admin' and SecretsManager-generated password
@@ -544,7 +488,7 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("credentials")
-        return typing.cast(typing.Optional[aws_cdk.aws_rds.Credentials], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_rds_ceddda9d.Credentials], result)
 
     @builtins.property
     def default_database_name(self) -> typing.Optional[builtins.str]:
@@ -581,7 +525,9 @@ class ServerlessClusterFromSnapshotProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def parameter_group(self) -> typing.Optional[aws_cdk.aws_rds.IParameterGroup]:
+    def parameter_group(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_rds_ceddda9d.IParameterGroup]:
         '''(deprecated) Additional parameters to pass to the database engine.
 
         :default: - no parameter group.
@@ -589,10 +535,10 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("parameter_group")
-        return typing.cast(typing.Optional[aws_cdk.aws_rds.IParameterGroup], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_rds_ceddda9d.IParameterGroup], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy]:
         '''(deprecated) The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update.
 
         :default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
@@ -600,10 +546,12 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy], result)
 
     @builtins.property
-    def scaling(self) -> typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions]:
+    def scaling(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions]:
         '''(deprecated) Scaling configuration of an Aurora Serverless database cluster.
 
         :default:
@@ -615,12 +563,12 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("scaling")
-        return typing.cast(typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions], result)
 
     @builtins.property
     def security_groups(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]]:
         '''(deprecated) Security group.
 
         :default: - a new security group is created.
@@ -628,10 +576,10 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("security_groups")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]], result)
 
     @builtins.property
-    def storage_encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
+    def storage_encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey]:
         '''(deprecated) The KMS key for storage encryption.
 
         If you specify the SnapshotIdentifier property, the StorageEncrypted property value is inherited from the snapshot, and if the DB cluster is encrypted, the specified KmsKeyId property is used.
@@ -641,10 +589,10 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("storage_encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey], result)
 
     @builtins.property
-    def subnet_group(self) -> typing.Optional[aws_cdk.aws_rds.ISubnetGroup]:
+    def subnet_group(self) -> typing.Optional[_aws_cdk_aws_rds_ceddda9d.ISubnetGroup]:
         '''(deprecated) Existing subnet group for the cluster.
 
         :default: - a new subnet group will be created.
@@ -652,10 +600,10 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("subnet_group")
-        return typing.cast(typing.Optional[aws_cdk.aws_rds.ISubnetGroup], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_rds_ceddda9d.ISubnetGroup], result)
 
     @builtins.property
-    def vpc_subnets(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+    def vpc_subnets(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection]:
         '''(deprecated) Where to place the instances within the VPC.
 
         :default: - the VPC default strategy if not specified.
@@ -663,7 +611,7 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         result = self._values.get("vpc_subnets")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -683,3 +631,73 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__02b4e7be41e42a4d0aba31d2cde08b3d9da054f652ab229cf3fcdf2fba029256(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    engine: _aws_cdk_aws_rds_ceddda9d.IClusterEngine,
+    snapshot_identifier: builtins.str,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    backup_retention: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+    cluster_identifier: typing.Optional[builtins.str] = None,
+    credentials: typing.Optional[_aws_cdk_aws_rds_ceddda9d.Credentials] = None,
+    default_database_name: typing.Optional[builtins.str] = None,
+    deletion_protection: typing.Optional[builtins.bool] = None,
+    enable_data_api: typing.Optional[builtins.bool] = None,
+    parameter_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.IParameterGroup] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    scaling: typing.Optional[typing.Union[_aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+    storage_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
+    subnet_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.ISubnetGroup] = None,
+    vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6fcef260575cff50f6020a8b1026eca3010c75a62054850c10123d8a2a5fcf86(
+    id: builtins.str,
+    *,
+    secret: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    automatically_after: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+    endpoint: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IInterfaceVpcEndpoint] = None,
+    exclude_characters: typing.Optional[builtins.str] = None,
+    vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e7470b0229ed4dc476cf44a05c9cace0d0dd92a87419e9ff947e198099945223(
+    grantee: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__55266b5c88e611e9ec1495d5d65d3a04e84a3c99a81ba74c3dc8a361e1d012f0(
+    value: typing.Optional[builtins.bool],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__19f89db333d90ee77c4f24c45d7dd089f98417f7ff36c23d822417ea3efe321c(
+    *,
+    engine: _aws_cdk_aws_rds_ceddda9d.IClusterEngine,
+    snapshot_identifier: builtins.str,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.IVpc,
+    backup_retention: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+    cluster_identifier: typing.Optional[builtins.str] = None,
+    credentials: typing.Optional[_aws_cdk_aws_rds_ceddda9d.Credentials] = None,
+    default_database_name: typing.Optional[builtins.str] = None,
+    deletion_protection: typing.Optional[builtins.bool] = None,
+    enable_data_api: typing.Optional[builtins.bool] = None,
+    parameter_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.IParameterGroup] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    scaling: typing.Optional[typing.Union[_aws_cdk_aws_rds_ceddda9d.ServerlessScalingOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+    storage_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
+    subnet_group: typing.Optional[_aws_cdk_aws_rds_ceddda9d.ISubnetGroup] = None,
+    vpc_subnets: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
